# plimai Documentation

Welcome to the plimai documentation!

## Overview
plimai is a modular framework for Vision LLMs with LoRA fine-tuning and a unified model zoo for open-source visual models.

## Contents
- [Getting Started](../README.md)
- [API Reference](api.md)
- [Model Zoo](model_zoo.md)
- [Contributing](../CONTRIBUTING.md) 